@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
+""""""
 
 from django.core.exceptions import PermissionDenied
 from django.contrib.auth.views import redirect_to_login
 from django.core.urlresolvers import reverse, NoReverseMatch
 
 class PermissionsMiddleware(object):
+    """Handle permission"""
+
     def process_exception(self, request, exception):
+        """manage ecxception"""
         if isinstance(exception, PermissionDenied) and (not request.user.is_authenticated()):
             try:
                 login_url = reverse('auth_login')
@@ -15,4 +19,3 @@ class PermissionsMiddleware(object):
                 except NoReverseMatch:
                     login_url = None
             return redirect_to_login(request.path, login_url)
-        
\ No newline at end of file
